/*
 * Copyright 2017-2019 original authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.micronaut.configuration.jmx.context;

import io.micronaut.inject.BeanDefinition;

import javax.management.MalformedObjectNameException;
import javax.management.ObjectName;

/**
 * Contract to create an {@link ObjectName} from a bean definition.
 *
 * @author James Kleeh
 * @since 1.0
 */
public interface NameGenerator {

    /**
     * Generates a management bean name from a bean definition.
     *
     * @param beanDefinition The bean definition
     * @return The bean {@link ObjectName}
     * @throws MalformedObjectNameException If the name is invalid
     */
    ObjectName generate(BeanDefinition<?> beanDefinition) throws MalformedObjectNameException;
}
